@@ -66,6 +66,7 @@ ENV_LANGUAGE_ID = 'LC_LANGUAGE_ID'
 ENV_JUPYTER_WORKSPACE = '/home/notebook/.jupyter/lab/workspaces'
 ENV_JUPYTER__HOME_DIR = '/home/work'
 
-BACK_END_API_URL = 'api.accu'
+# BACK_END_API_URL = 'api.accu'
+BACK_END_API_URL = 'localhost'
 BACK_END_API_PORT = '8080'
 BACK_END_API_URI = ''
