@@ -10,6 +10,9 @@ from Accuinsight.modeler.protos import skapi_pb2
 from Accuinsight.modeler.utils.proto_json_utils import parse_dict
 from Accuinsight.modeler.utils.string_utils import strip_suffix
 from Accuinsight.modeler.exceptions import ModelerException, RestException
+from Accuinsight.modeler.core.Run.RunInfo.RunInfo import get_current_run
+from Accuinsight.modeler.core.LcConst.LcConst import RUN_RESULT_PATH
+# from Accuinsight.modeler.core.LcConst.LcConst import RUN_MODEL_SHAP_JSON_PATH
 
 RESOURCE_DOES_NOT_EXIST = 'RESOURCE_DOES_NOT_EXIST'
 
@@ -188,6 +191,15 @@ def _make_parameter_data(json_body):
 def _make_feature_data(json_body):
     json_body['feature'] = {}
     json_body['feature']['importance'] = {}
+
+    run_info_json = get_current_run()
+    run_result_path = run_info_json[RUN_RESULT_PATH]
+    json_path = run_result_path[RUN_MODEL_SHAP_JSON_PATH]
+    if json_path:
+        with open(json_path) as json_file:
+            shap_json_data = json.load(json_file)
+        json_body['feature']['importance'] = shap_json_data
+
     return json_body
 
 def call_endpoint(host_creds, endpoint, method, json_body, response_proto):
